Crate decondenser

Crate decondenser 

The API of this crate is not stable yet! It’s not yet intended for public use.

Functions

decondense
The main function of this crate that decondenses the input according to the nesting of the following groups of characters: (), [], {}.
unescape
Unescape the string by replacing the escape sequences with their actual characters. Supported escape sequences are: